package net.wanji.web.common.entity;

import net.wanji.web.common.enums.StatusCode;

/**
 * HTTP响应类
 *
 * @author Kent HAN
 * @date 2022/10/26 15:48
 */

public class Result<T> {
    private String status;
    private String msg;
    private T data;

    private Result(T data) {
        this.status = StatusCode.SUCCESS.getStatus();
        this.msg = StatusCode.SUCCESS.getMsg();
        this.data = data;
    }

    private Result(StatusCode statusCode) {
        if (statusCode == null) {
            return;
        }
        this.status = statusCode.getStatus();
        this.msg = statusCode.getMsg();
    }

    private Result(StatusCode statusCode, String msg) {
        if (statusCode == null) {
            return;
        }
        this.status = statusCode.getStatus();
        this.msg = statusCode.getMsg() + "--" + msg;
    }

    /**
     * 成功时候的调用
     */
    public static <T> Result<T> success(T data) {
        return new Result<T>(data);
    }

    /**
     * 成功，不需要传入参数
     */
    @SuppressWarnings("unchecked")
    public static <T> Result<T> success() {
        return (Result<T>) success("");
    }

    /**
     * 失败时候的调用
     */
    public static <T> Result<T> error(StatusCode statusCode) {
        return new Result<T>(statusCode);
    }

    /**
     * 失败时候的调用,扩展消息参数
     */
    public static <T> Result<T> error(StatusCode statusCode, String msg) {
        return new Result<T>(statusCode, msg);
    }

    public T getData() {
        return data;
    }

    public String getStatus() {
        return status;
    }

    public String getMsg() {
        return msg;
    }
}