package net.wanji.web.controller;

import net.wanji.web.common.entity.JsonViewObject;
import net.wanji.web.common.exception.CrossRelationException;
import net.wanji.web.service.SpecialServiceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.web.vo.specialService.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;
import java.util.List;
import java.util.Set;

/**
 * 快速特勤
 *
 * @author Kent HAN
 * @date 2022/11/8 10:57
 */
@Api(value = "SpecialServiceController", description = "快速特勤")
@RequestMapping("/specialService")
@RestController
public class SpecialServiceController {
    @Autowired
    SpecialServiceService specialServiceService;

    @ApiOperation(value = "添加特勤", notes = "添加特勤", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/addSpecialService",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject addSpecialService(@RequestBody AddSpecialServiceInVO addSpecialServiceInVO) {
        specialServiceService.addSpecialService(addSpecialServiceInVO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success();
    }

    @ApiOperation(value = "特勤列表", notes = "特勤列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/listSpecialServices",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = ListSpecialServicesOutVO.class),
    })
    public JsonViewObject listSpecialServices(@RequestBody ListSpecialServicesInVO listSpecialServicesInVO) {
        String adCode = listSpecialServicesInVO.getAdCode();
        List<ListSpecialServicesOutVO> listSpecialServicesOutVOList = specialServiceService.listSpecialServices(adCode);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(listSpecialServicesOutVOList);
    }

    @ApiOperation(value = "编辑特勤", notes = "编辑特勤", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/updateSpecialService",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject updateSpecialService(@RequestBody UpdateSpecialServiceInVO updateSpecialServiceInVO) {
        specialServiceService.updateSpecialService(updateSpecialServiceInVO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success();
    }

    @ApiOperation(value = "删除特勤", notes = "删除特勤", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/deleteSpecialService",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject deleteSpecialService(@RequestBody DeleteSpecialServiceInVO deleteSpecialServiceInVO) {
        Integer id = deleteSpecialServiceInVO.getId();
        specialServiceService.deleteSpecialService(id);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success();
    }

    @ApiOperation(value = "添加路口", notes = "添加路口", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/addCross",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject addCross(@RequestBody AddCrossInVO addCrossInVO) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try {
            specialServiceService.addCross(addCrossInVO);
            return jsonViewObject.success();
        } catch (CrossRelationException e) {
            return jsonViewObject.fail("路段关系不正确");
        }
    }

    @ApiOperation(value = "路口列表", notes = "路口列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/crossList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossListOutVO.class),
    })
    public JsonViewObject crossList(@RequestBody CrossListInVO crossListInVO) {
        Integer specialServiceId = crossListInVO.getSpecialServiceId();
        List<CrossListOutVO> crossListOutVOList = specialServiceService.crossList(specialServiceId);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(crossListOutVOList);
    }

    @ApiOperation(value = "更新路口", notes = "更新路口", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/updateCross",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject updateCross(@RequestBody UpdateCrossInVO updateCrossInVO) {
        specialServiceService.updateCross(updateCrossInVO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success();
    }

    @ApiOperation(value = "删除路口", notes = "删除路口", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/deleteCross",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject deleteCross(@RequestBody DeleteCrossInVO deleteCrossInVO) {
        specialServiceService.deleteCross(deleteCrossInVO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success();
    }

    @ApiOperation(value = "一键特勤", notes = "一键特勤", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/enableSpecialService",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject enableSpecialService(@RequestBody EnableDisableSpecialServiceInVO enableDisableSpecialServiceInVO) {
        specialServiceService.enableSpecialService(enableDisableSpecialServiceInVO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success();
    }

    @ApiOperation(value = "一键取消特勤", notes = "一键取消特勤", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/disableSpecialService",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject disableSpecialService(@RequestBody EnableDisableSpecialServiceInVO enableDisableSpecialServiceInVO) {
        specialServiceService.disableSpecialService(enableDisableSpecialServiceInVO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success();
    }

    @ApiOperation(value = "路口进口列表", notes = "路口进口列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/crossInList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject crossInList(@RequestBody CrossIdVO crossIdVO) {
        String crossId = crossIdVO.getCrossId();
        Set<String> crossInList = specialServiceService.crossInList(crossId);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(crossInList);
    }
}
