package net.wanji.web.controller.scheme;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.web.common.entity.JsonViewObject;
import net.wanji.web.dto.CrossIdDTO;
import net.wanji.web.service.scheme.impl.CrossConfigServiceImpl;
import net.wanji.web.vo.scheme.CrossDirsVO;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;

/**
 * @author Kent HAN
 * @date 2022/12/20 10:14
 */
@Api(value = "CrossConfigController", description = "方案管理-路口配置")
@RequestMapping("/crossConfig")
@RestController
public class CrossConfigController {
    private final CrossConfigServiceImpl crossConfigServiceImpl;

    public CrossConfigController(CrossConfigServiceImpl crossConfigServiceImpl) {
        this.crossConfigServiceImpl = crossConfigServiceImpl;
    }

    @ApiOperation(value = "获取路口方向列表", notes = "获取路口方向列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/listCrossDirs",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossDirsVO.class),
    })
    public JsonViewObject listCrossDirs(@RequestBody CrossIdDTO crossIdDTO) {
        String crossId = crossIdDTO.getCrossId();
        CrossDirsVO crossDirsVO = crossConfigServiceImpl.listCrossDirs(crossId);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(crossDirsVO);
    }
}
