package net.wanji.web.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.support.SFunction;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import net.wanji.web.common.Result;
import net.wanji.web.common.enums.CrossTypeEnum;
import net.wanji.web.entity.TBaseAreaInfo;
import net.wanji.web.entity.TBaseCrossInfo;
import net.wanji.web.mapper.TBaseAreaInfoMapper;
import net.wanji.web.mapper.TBaseCrossInfoMapper;
import net.wanji.web.po.AreaTreePO;
import net.wanji.web.po.CrossInfoPO;
import net.wanji.web.po.PageResultPO;
import net.wanji.web.util.IdWorker;
import net.wanji.web.vo.BaseCrossInfoVO;
import net.wanji.web.vo.CrossInfoVO;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 路口基础表 服务实现类
 * </p>
 *
 * @author wj
 * @since 2022-11-28
 */
@Service
public class TBaseCrossInfoService extends ServiceImpl<TBaseCrossInfoMapper, TBaseCrossInfo> implements IService<TBaseCrossInfo> {

    @Autowired
    private TBaseCrossInfoMapper crossInfoMapper;

    @Autowired
    private TBaseAreaInfoMapper areaInfoMapper;


    /**
     * 查询
     *
     * @param crossInfoVO 查询路口管理输入参数
     * @return {@link Result}<{@link PageResultPO}<{@link CrossInfoPO}>>
     */
    public Result<PageResultPO<CrossInfoPO>> selectAll(CrossInfoVO crossInfoVO) {
        PageResultPO<CrossInfoPO> page = new PageResultPO<>();
        Integer count = crossInfoMapper.countSelectAll(crossInfoVO);
        List<CrossInfoPO> list = crossInfoMapper.selectAll(crossInfoVO);
        page.setPageNum(crossInfoVO.getPageNum());
        page.setPageSize(crossInfoVO.getPageSize());
        page.setTotal(count);
        page.setData(list);
        return Result.success(page);
    }

    /**
     * 添加
     *
     * @param crossInfoPO 增加路口管理输入参数
     * @return {@link Result}<{@link String}>
     */
    public Result<String> addOne(BaseCrossInfoVO crossInfoPO) {
        TBaseCrossInfo record = getBaseCrossInfo(crossInfoPO);
        record.setGmtCreate(new Date());
        int insert = crossInfoMapper.insertSelective(record);
        if (insert > 0) {
            return Result.success("添加成功");
        }
        return Result.error("添加失败");
    }

    /**
     * 更新
     *
     * @param crossInfoPO 修改路口管理输入参数
     * @return {@link Result}<{@link String}>
     */
    public Result<String> updateOne(BaseCrossInfoVO crossInfoPO) {
        TBaseCrossInfo record = new TBaseCrossInfo();
        BeanUtils.copyProperties(crossInfoPO, record);
        record.setGmtModified(new Date());
        int update = crossInfoMapper.updateByPrimaryKeySelective(record);
        if (update > 0) {
            return Result.success("修改成功");
        }
        return Result.error("修改失败");
    }

    private TBaseCrossInfo getBaseCrossInfo(BaseCrossInfoVO crossInfoPO) {
        if (crossInfoPO.getId() == null || crossInfoPO.getId().trim().equals("")) {
            IdWorker idWorker = new IdWorker(0, 0);
            crossInfoPO.setId(String.valueOf(idWorker.nextId()));
        }
        if (crossInfoPO.getAreaCode() == null) {
            QueryWrapper<TBaseAreaInfo> queryWrapper = new QueryWrapper<>();
            queryWrapper.lambda().like(TBaseAreaInfo::getName, crossInfoPO.getAreaName());
            // 查询areaCode
            List<TBaseAreaInfo> tBaseAreaInfos = areaInfoMapper.selectList(queryWrapper);
            if (tBaseAreaInfos != null && tBaseAreaInfos.size() > 0) {
                crossInfoPO.setAreaCode(tBaseAreaInfos.get(0).getCode());
            }
        }
        if (crossInfoPO.getAreaName() == null) {
            QueryWrapper<TBaseAreaInfo> queryWrapper = new QueryWrapper<>();
            queryWrapper.lambda().eq(TBaseAreaInfo::getCode, crossInfoPO.getAreaCode());
            List<TBaseAreaInfo> tBaseAreaInfos = areaInfoMapper.selectList(queryWrapper);
            if (tBaseAreaInfos != null && tBaseAreaInfos.size() > 0) {
                crossInfoPO.setAreaName(tBaseAreaInfos.get(0).getName());
            }
        }
        if (crossInfoPO.getType() == null) {
            crossInfoPO.setType(CrossTypeEnum.OTHER.getCode());
        }
        if (crossInfoPO.getLevel() == null) {
            crossInfoPO.setLevel(0);
        }
        if (crossInfoPO.getIsSend() == null) {
            crossInfoPO.setIsSend(1);
        }
        if (crossInfoPO.getIsSignal() == null) {
            crossInfoPO.setIsSignal(1);
        }
        if (crossInfoPO.getIsStart() == null) {
            crossInfoPO.setIsStart(1);
        }
        if (crossInfoPO.getLocation() == null) {
            crossInfoPO.setLocation("null");
        }
        TBaseCrossInfo record = new TBaseCrossInfo();
        BeanUtils.copyProperties(crossInfoPO, record);
        record.setGmtModified(new Date());
        return record;
    }

    /**
     * 删除
     *
     * @param ids id集合
     * @return {@link Result}<{@link String}>
     */
    public Result<String> delete(List<String> ids) {
        crossInfoMapper.deleteBatchIds(ids);
        return Result.success("删除成功");
    }


    /**
     * 区域名称下拉框
     *
     * @return {@link Result}<{@link AreaTreePO}>
     */
    public Result<List<AreaTreePO>> areaTree() {
        List<AreaTreePO> infos = areaInfoMapper.selectAreaTree();
        // 构建树
        Map<Integer, List<AreaTreePO>> parentCodeMap = infos.stream().collect(Collectors.groupingBy(AreaTreePO::getParentCode));
        for (AreaTreePO info : infos) {
            for (Integer parentCode : parentCodeMap.keySet()) {
                if (info.getAreaCode().equals(parentCode)) {
                    info.setChildren(parentCodeMap.get(parentCode));
                    break;
                }
            }
        }
        infos = infos.stream().filter(po -> po.getParentCode() == null || po.getParentCode().equals(100000)).collect(Collectors.toList());
        return Result.success(infos);
    }
}
