package net.wanji.web.service.scheme.impl;

import net.wanji.web.common.enums.CrossDirEnum;
import net.wanji.web.common.enums.CrossInOutEnum;
import net.wanji.web.mapper.scheme.CrossDirInfoMapper;
import net.wanji.web.po.scheme.CrossDirInfoPO;
import net.wanji.web.service.scheme.CrossConfigService;
import net.wanji.web.vo.scheme.CrossDirsVO;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Kent HAN
 * @date 2022/12/20 10:27
 */
@Service
public class CrossConfigServiceImpl implements CrossConfigService {
    private final CrossDirInfoMapper crossDirInfoMapper;

    public CrossConfigServiceImpl(CrossDirInfoMapper crossDirInfoMapper) {
        this.crossDirInfoMapper = crossDirInfoMapper;
    }

    @Override
    public CrossDirsVO listCrossDirs(String crossId) {
        List<CrossDirInfoPO> crossDirInfoPOList = crossDirInfoMapper.listByCrossID(crossId);
        CrossDirsVO crossDirsVO = new CrossDirsVO();
        crossDirsVO.setCrossId(crossId);
        ArrayList<String> dirs = new ArrayList<>();
        for (CrossDirInfoPO crossDirInfoPO : crossDirInfoPOList) {
            Integer inOutTypeCode = crossDirInfoPO.getInOutType();
            if (inOutTypeCode == 1) { // 只取进口
                Integer dirTypeCode = crossDirInfoPO.getDirType();
                String dirType = CrossDirEnum.getMsgByCode(dirTypeCode);
                String inOutType = CrossInOutEnum.getMsgByCode(inOutTypeCode);
                String dir = dirType + inOutType;
                dirs.add(dir);
            }
        }
        crossDirsVO.setCrossDirs(dirs);
        return crossDirsVO;
    }
}
